@@ -3,7 +3,9 @@ from pathlib import Path
 from typing import Any, Callable, List, Optional, Sequence
 
 from databooks import JupyterNotebook
-from databooks.common import get_logger, set_verbose, write_notebook
+from databooks.common import write_notebook
+from databooks.data_models.notebook import Cell
+from databooks.logging import get_logger, set_verbose
 
 logger = get_logger(__file__)
 
@@ -13,6 +15,7 @@ def clear(
     write_path: Optional[Path] = None,
     notebook_metadata_keep: Sequence[str] = (),
     cell_metadata_keep: Sequence[str] = (),
+    cell_fields_keep: List[str] = [],
     check: bool = False,
     verbose: bool = False,
     **kwargs: Any,
@@ -26,6 +29,7 @@ def clear(
     :param write_path: Path of notebook file with metadata to be cleaned
     :param notebook_metadata_keep: Notebook metadata fields to keep
     :param cell_metadata_keep: Cell metadata fields to keep
+    :param cell_fields_keep: Cell fields to keep
     :param check: Don't write any files, check whether there is unwanted metadata
     :param verbose: Log written files
     :param kwargs: Additional keyword arguments to pass to
@@ -39,9 +43,18 @@ def clear(
         write_path = read_path
     notebook = JupyterNotebook.parse_file(read_path)
 
+    # Get fields to remove from cells
+    cell_fields = {field for cell in notebook.cells for field, _ in cell if field}
+    cell_fields_keep += list(Cell.__fields__)  # required field for notebook schema
+
+    cell_remove_fields = [
+        field for field in cell_fields if field not in cell_fields_keep
+    ]
+
     notebook.clear_metadata(
         notebook_metadata_keep=notebook_metadata_keep,
         cell_metadata_keep=cell_metadata_keep,
+        cell_remove_fields=cell_remove_fields,
         **kwargs,
     )
     nb_equals = notebook == JupyterNotebook.parse_file(read_path)
